Module tile_cache_integration

Module tile_cache_integration 

Integration between TileCache and NavMesh for real-time updates

This module provides functionality to rebuild navigation mesh tiles when tile cache data changes due to obstacle updates.

Structs

TileCacheNavMeshIntegration
Integration manager for TileCache and NavMesh