TileCacheNavMeshIntegration

Struct TileCacheNavMeshIntegration 

pub struct TileCacheNavMeshIntegration { /* private fields */ }
Integration manager for TileCache and NavMesh

Implementations

Source

impl TileCacheNavMeshIntegration

pub fn new(builder_config: TileCacheBuilderConfig) -> Self

Creates a new integration manager

pub fn build_nav_mesh_tile_from_layer( &self, tile_cache: &TileCache, nav_mesh: &mut NavMesh, tile_layer: &TileCacheLayer, tile_idx: usize, ) -> Result<(), TileCacheError>

Builds a navigation mesh tile from a tile layer

pub fn rebuild_tile_in_nav_mesh( &self, tile_cache: &TileCache, nav_mesh: &mut NavMesh, tile_idx: usize, ) -> Result<Option<PolyRef>, TileCacheError>

Rebuilds a tile in the navigation mesh from tile cache data

pub fn update_all_affected_tiles( &self, tile_cache: &mut TileCache, nav_mesh: &mut NavMesh, ) -> Result<Vec<PolyRef>, TileCacheError>

Updates all tiles affected by obstacles in the tile cache

pub fn get_builder_config(&self) -> &TileCacheBuilderConfig

Gets the builder configuration