Tile cache builder for real-time mesh rebuilding
This module provides functionality to rebuild navigation mesh tiles from compressed tile cache data, with support for dynamic obstacles.
Structs
- Tile
Cache Builder - Tile cache builder for converting cached layers to navigation mesh tiles