Integration between TileCache and NavMesh for real-time updates
This module provides functionality to rebuild navigation mesh tiles when tile cache data changes due to obstacle updates.
Structs
- Tile
Cache NavMesh Integration - Integration manager for TileCache and NavMesh