pub struct TileCacheNavMeshIntegration { /* private fields */ }Expand description
Integration manager for TileCache and NavMesh
Implementations
Sourcepub fn new(builder_config: TileCacheBuilderConfig) -> Self
pub fn new(builder_config: TileCacheBuilderConfig) -> Self
Creates a new integration manager
Builds a navigation mesh tile from a tile layer
Rebuilds a tile in the navigation mesh from tile cache data
Sourcepub fn update_all_affected_tiles(
&self,
tile_cache: &mut TileCache,
nav_mesh: &mut NavMesh,
) -> Result<Vec<PolyRef>, TileCacheError>
pub fn update_all_affected_tiles( &self, tile_cache: &mut TileCache, nav_mesh: &mut NavMesh, ) -> Result<Vec<PolyRef>, TileCacheError>
Updates all tiles affected by obstacles in the tile cache
Sourcepub fn get_builder_config(&self) -> &TileCacheBuilderConfig
pub fn get_builder_config(&self) -> &TileCacheBuilderConfig
Gets the builder configuration